CTF Rest Dataset
----------------

The data used in this example is part of the [MRC MEGUK](https://meguk.ac.uk/about/) partnership and is from the Nottingham site. In these scripts we focus on the resting-state (eyes open) MEG data.

Example scripts for preprocessing and source reconstructing CTF data are contained in `/preproc`.
